% SocNetParallelFinishRemote.m
% SOCNETPARALLELREMOTE processes output files from SocNetParallelFile on TUC
% by displaying output files, creating a histogram of degree distributions
% for a people-to-people graph, and displaying the mean clustering
% coefficient.
% This processes social networks files for job j.
% Script is derived from poolJobRemote.m downloaded from Cornell Center for Advanced Computing
% "User Documentation" at http://www.cac.cornell.edu/matlab/TechDocs/Examples/Default.aspx

alltasks = get(j, 'Tasks');
% display errors displayed in command window
a = get(alltasks, 'Error');
disp(a);

% display the command window output
a = get(alltasks,'CommandWindowOutput');
disp(a);
disp(a{1});

destroy(j);

% download output files
% ftp.get('out_setup_sample_activities_2labs_2Labs.txt', 'out_setup_sample_activities_2labs_2Labs.txt');
ftp.get('out_setup_rand_7000Els_7Labs.txt', 'out_setup_rand_7000Els_7Labs.txt');
ftp.get('out_people.txt', 'out_people.txt');
ftp.get('out_locations.txt', 'out_locations.txt');
ftp.get('out_degs.txt', 'out_degs.txt');
ftp.get('out_coeffLst.txt', 'out_coeffLst.txt');

% put results in matrices
people = load('out_people.txt');
locations = load('out_locations.txt');
degs = load('out_degs.txt');
coeffLst = load('out_coeffLst.txt');

% Process locally the returned parameters
% fractionPeople defined in SocNetParallelStartRemote.m
disp(['Minimum dominating set for ' num2str(fractionPeople) ' fraction of the people:  ']);
disp(locations);
disp('Set of people dominated by these locations:  ' );
disp(people);
disp(' ');

% construct histogram
numCategories = max(degs) + 1;  % number of categories for histogram
figure;
hist(degs, numCategories);
xlabel('Degree');
ylabel('Number');

disp(['Mean degree = ', num2str(mean(degs))]);  % average degree
disp(' ');

% Uncomment the next two linew to display all clustering coefficients
% disp('Clustering coefficients:');
% disp(coeffLst);
disp(['Mean clustering coefficient = ' num2str(mean(coeffLst))]);
